@@ -30,15 +30,15 @@ use vars qw($VERSION @EXPORT_OK %EXPORT_TAGS);
 
 =head1 NAME
 
-CGI::Application::Plugin::PageLookup - Database driven model framework for CGI::Application
+CGI::Application::Plugin::PageLookup - Database driven model framework for CGI::Applicaition
 
 =head1 VERSION
 
-Version 1.6_5
+Version 1.1
 
 =cut
 
-our $VERSION = '1.6_5';
+our $VERSION = '1.1';
 
 =head1 DESCRIPTION
 
@@ -143,9 +143,7 @@ page and that provides support for multiple languages and the 'dot' notation in
 
 =head1 DATABASE
 
-Something like the following schema is assumed. In general each column on these tables 
-corresponds to a template parameter that needs to be on every page on the website and each row in the join
-corresponds to a page on the website. The exact types are not required and can be changed
+Something like the following schema is assumed. The exact types are not required and can be changed
 but these are the recommended values. The lang and internalId columns combined should be as unique as the pageId 
 column. They are used to link the different language versions of the same page and also the page with 
 nearby pages in the same language. The lang column is used to join the two pages. The lang and collation fields expect
@@ -158,9 +156,7 @@ The changefreq field is also used in setting the expiry header. Since these fiel
 by default they are deleted just before being sent to the template. The lineage and rank columns are used by menu/sitemap 
 functionality and together should be unique.
 
-=over
-
-=item Table: cgiapp_structure
+Table: cgiapp_structure
 
  Field        Type                                                                Null Key  Default Extra 
  ------------ ------------------------------------------------------------------- ---- ---- ------- -----
@@ -169,10 +165,10 @@ functionality and together should be unique.
  lastmod      date                                                                NO        NULL          
  changefreq   enum('always','hourly','daily','weekly','monthly','yearly','never') NO        NULL          
  priority     decimal(3,3)                                                        YES       NULL          
- lineage      varchar(255)                                                        NO   UNI  NULL    	 
- rank	      unsigned numeric(10,0)                                              NO   UNI  NULL    	 
+ lineage      varchar(255)                                                        NO        NULL    	 
+ rank	      unsigned numeric(10,0)                                              NO        NULL    	 
 
-=item Table: cgiapp_pages
+Table: cgiapp_pages
 
  Field        Type                                                                Null Key  Default Extra 
  ------------ ------------------------------------------------------------------- ---- ---- ------- -----
@@ -180,18 +176,16 @@ functionality and together should be unique.
  lang         varchar(2)       	                                                  NO   PRI  NULL          
  internalId   unsigned numeric(10,0)                                              NO   PRI  NULL          
 
- + any custom columns that the web application might require.
++ any custom columns that the web application might require.
 
-=item Table: cgiapp_lang
+Table: cgiapp_lang
 
  Field        Type                                                                Null Key  Default Extra 
  ------------ ------------------------------------------------------------------- ---- ---- ------- -----
  lang         varchar(2)                                                          NO   PRI  NULL          
  collation    varchar(2)                                                          NO        NULL          
 
- + any custom columns that the web application might require.
-
-=back
++ any custom columns that the web application might require.
 
 =head1 EXPORT
 
@@ -237,7 +231,7 @@ because the pagelookup function will return undef.
 
 =item expiry
 
-If set (which it is by default), the pagelookup function will set the appropriate
+If set (which it is by default), the pagelookup function will will set the appropriate
 expiry header based upon the changefreq column.
 
 =item remove
@@ -247,11 +241,11 @@ It defaults to template, pageId and internalId, changefreq.
 
 =item objects
 
-This points to a hash ref. Each key is a parameter name (upto the dot). The value
+This points to a hash ref. Each key is a paramater name (upto the dot). The value
 is something that defines a smart object as described in L<HTML::Template::Plugin::Dot>.
 The point about a smart object is that usually it defines an AUTOLOAD function so if the template
 has <TMPL_VAR NAME="object.getcarter"> and the pagelookup_config has mapped object to some
-object $MySmartObject then the method $MySmartObject->getcarter() will be called. Alternatively
+object $MySmartObject then the method $MySmartObject->getcarter() will be called. Alternaitively
 there may be no AUTOLOAD function but the smart object may have methods that take additional arguments.
 This way the template can be much more decoupled from the structure of the database.
 
@@ -306,7 +300,7 @@ cannot otherwise be guessed.
 
 =item status_404
 
-This is the internal id corresponding to the not found page.
+This is the core id corresponding to the not found page.
 
 =item msg_param
 
@@ -345,7 +339,7 @@ sub pagelookup_config {
 
 =head2 pagelookup_get_config 
 
-Returns config including any overrides passed in as arguments.
+Returns config including any overrides passed in as aeguments.
 
 =cut
 
@@ -384,8 +378,6 @@ sub pagelookup_prefix {
 =head2 pagelookup_sql 
 
 This function returns the SQL that is used to lookup a specific page.
-It takes a single argument which is usually expected to be a pageId.
-This may also be taken in the form of a HASH ref having two fields: internalId and lang.
 
 =cut
 
@@ -393,11 +385,6 @@ sub pagelookup_sql {
    my $self = shift;
    my $page_id = shift;
    my $prefix = $self->pagelookup_prefix(@_);
-   if (ref($page_id) eq "HASH") {
-	croak "internalId expected" unless exists $page_id->{internalId};
-	croak "lang expected" unless exists $page_id->{lang};
- 	return "SELECT s.template, s.changefreq, p.*, l.* FROM ${prefix}pages p, ${prefix}lang l, ${prefix}structure s WHERE p.lang = l.lang AND p.lang = '$page_id->{lang}' AND p.internalId = s.internalId AND p.internalId = $page_id->{internalId}";
-   }
    return "SELECT s.template, s.changefreq, p.*, l.* FROM ${prefix}pages p, ${prefix}lang l, ${prefix}structure s WHERE p.lang = l.lang AND p.pageId = '$page_id' AND p.internalId = s.internalId";
 }
 
@@ -414,8 +401,6 @@ arguments overriding the default config. Then the sequence of events is as follo
 7.) Put the parameters into the template object.
 8.) Return the now partially or completely filled template object.
 
-The page id may also be taken in the form of a HASH ref having two fields: internalId and lang.
-
 =cut
 
 sub pagelookup {
@@ -440,8 +425,6 @@ sub pagelookup {
 	return undef;
    }
 
-   $page_id = $hash_ref->{pageId} if ref($page_id) eq "HASH";
-
    # Load the template
    my $template = $self->load_tmpl($hash_ref->{template}, %{$args{template_params}});
 
@@ -469,9 +452,7 @@ sub pagelookup {
 		$object = $self->$ovalue($page_id, $template, $okey, @inargs);
 	}
 	else {
-		use UNIVERSAL::require;
 		$object = eval {
-			$ovalue->require;
 			return $ovalue->new($self, $page_id, $template, $okey, @inargs);
 		};
 		croak "Could not create smart object: $okey: $@" if $@;
@@ -548,8 +529,8 @@ This function takes a page id which has failed a page lookup and tries to find t
 404 page. First of all it attempts to find the correct by language by assuming that if the first three 
 characters of the page id consists of two characters followed by a '/'. If this matches then the first
 two characters are taken to be the language. If that fails then the language is taken to be $self->pagelookup_default_lang.
-Then the relevant 404 page is looked up by language and internal id. The internalId is taken to be $self->pagelookup_404 . 
-Of course it is assumed that this page lookup cannot fail. The header  404 status is added
+Then the page id of the relevant 404 page is taken to be [the language]+'/'+$self->pagelookup_404 . Having obtained a 
+a pgae id the page is looked up. Of course it is assumed that this page lookup cannot fail. The header  404 status is added
 to the header and the original page id is inserted into the $self->pagelookup_msg_param parameter.
 If this logic does not match your URL structure you can omit exporting this function or turn notfound handling off
 and implement your own logic.
@@ -568,7 +549,10 @@ sub pagelookup_notfound {
 	$lang = $1;
    }
 
-   my $template = $self->pagelookup({lang=>$lang, internalId => $self->pagelookup_404}, handle_notfound=>0) || croak "failed to construct 'not found' page";
+   # Get new page id
+   my $new_page_id = "$lang/".($self->pagelookup_404(@inargs));
+
+   my $template = $self->pagelookup($new_page_id, handle_notfound=>0) || croak "failed to construct 'not found' page";
    $template->param( $self->pagelookup_msg_param(@inargs) => $page_id);
    $self->header_add( -status => 404 );
    return $template;
@@ -657,13 +641,6 @@ Nicholas Bamber, C<< <nicholas at periapt.co.uk> >>
 
 =head1 BUGS
 
-Currently errors are not trapped early enough and hence error messages are less informative than they might be.
-
-Also we are working on validating the code against more L<DBI> drivers. Currently mysql and SQLite are known to work.
-It is known to be incompatible with postgres, which should be fixed in the next release. This may entail schema changes.
-It is also known to be in incompatible with L<DBD::DBM>, apparently on account of a join across three tables.
-The SQL is not ANSI standard and that is one possible change. Another approach may be to make the schema configurable.
-
 Please report any bugs or feature requests to C<bug-cgi-application-plugin-pagelookup at rt.cpan.org>, or through
 the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=CGI-Application-Plugin-PageLookup>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
@@ -700,8 +677,6 @@ L<http://search.cpan.org/dist/CGI-Application-Plugin-PageLookup/>
 
 =head1 ACKNOWLEDGEMENTS
 
-Thanks to JavaFan for suggesting the use of L<Test::Database>. Thanks to  Philippe Bruhat
-for help with getting Test::Database to work more smoothly.
 
 =head1 COPYRIGHT & LICENSE
 
