@@ -6,15 +6,16 @@ use Carp;
 
 =head1 NAME
 
-CGI::Application::Plugin::PageLookup::Menu - Support for consistent menus across a multilingual website
+CGI::Application::Plugin::PageLookup::Menu - Support for consistent menus across a multilanguage website
 
 =head1 VERSION
 
-Version 1.6_5
+Version 1.1
 
 =cut
 
-our $VERSION = '1.6_5';
+our $VERSION = '1.1';
+our $AUTOLOAD;
 
 =head1 DESCRIPTION
 
@@ -24,7 +25,7 @@ if the URLs are kept the same apart from a language identifier. This means that
 would have  search engine friendly in only one language. The L<CGI::Application::Plugin::PageLookup::Href> module
 could be used to create a static menu and site map that is automatically translated into various languages
 with search engine friendly URLs. However they cannot be combined as you cannot pass through first the Loop and then the Href.
-What this module offers is a specialised variant of the Loop smart object that does combine these features.
+What this module offers is a specialized variant of the Loop smart object that does combine these features.
 This module depends on L<CGI::Application::Plugin::PageLookup>.
 
 =head1 SYNOPSIS
@@ -104,7 +105,7 @@ The module can be used to get data either for menus or human readable sitemaps.
 =item 
 
 One value that will always be returned is the 'pageId' column which can be translated into a URL as dictated
-by the website policy. However due to capitalisation issues, you must either call it 'pageid' in the template 
+by the website's policy. However due to capitalization issues, you must either call it 'pageid' in the template 
 or specify 'case_sensitive => 1' somewhere in the template infrastructure.
 
 =item
@@ -129,7 +130,7 @@ Nor have we tried testing varying the arguments at different levels of the menu
 
 =head2 new
 
-A constructor following the requirements set out in L<CGI::Application::Plugin::PageLookup>.
+A constructor folowing the requirements set out in L<CGI::Application::Plugin::PageLookup>.
 
 =cut
 
@@ -151,40 +152,24 @@ sub new {
 
 This function is specified in the template where additional columns are specified. 
 If no arguments are specified only the 'pageId' column is returned for each menu item.
-Additional arguments should be specified either as a single comma separated string (deprecated)
-or as multiple arguments.
+Additional arguments should be specified as a single comma separated string.
 
 =cut
 
 sub structure {
 	my $self = shift;
-	my @params = @_;
-	my $template = "$self->{name}.structure('";
-	if (scalar(@params) == 1) {
-		# legacy case
-		$template .= "$params[0]')";
-		@params = split /,/, $params[0];
-	}
-	else {
-		$template .= join "','", @params;
-		$template .= "')";
-	}
-	return $self->__structure(\@params, "", [$template]);
-}
-
-sub __structure {
-	my $self = shift;
-	my @params = @{shift || []};
+	my $param = shift || "";
 
         # $dlineage are the "breadcrumbs" required to navigate our way through the database
 	# and corresponds to the 'lineage' column on the cgiapp_structure table.
 	my $dlineage = shift;
-	croak "database lineage missing" unless defined $dlineage;
+	$dlineage = "" unless defined $dlineage;
 
 	# $tlineage are the "breadcrumbs" required to navigate our way through the HTML::Template structure.
-	# It corresponds to the ARRAY ref used in $template->query(loop=> [....]).
+	# It corresponds to the ARRAY ref used in $template->query(loop=> [....]) only that the
+	# post "dot" string of the final array member (aka structure('$param')) is missing.
 	my $tlineage = shift;
-	croak "template lineage missing" unless defined $tlineage;
+	$tlineage = [$self->{name}] unless defined $tlineage;
 
         my $prefix = $self->{cgiapp}->pagelookup_prefix(%{$self->{config}});
         my $page_id = $self->{page_id};
@@ -196,11 +181,11 @@ sub __structure {
 	$self->{work_to_be_done} = [] unless exists $self->{work_to_be_done};
 
 	# generate SQL: get menu structure but optionally pull extra columns from cgiapp_pages
-	my @params_sql;
+	my @params = split /,/ , $param;
 	foreach my $p (@params) {
-		push @params_sql, ", p2.$p";
+		$p = ", p2.$p";
 	}
-	my $param_sql = join "", @params_sql;
+	my $param_sql = join "", @params;
         my $sql = "SELECT s.rank, p2.pageId $param_sql FROM ${prefix}structure s, ${prefix}pages p2, ${prefix}pages p1 WHERE p1.lang = p2.lang AND s.internalId = p2.internalId AND p1.pageId = '$page_id' AND s.lineage = '$dlineage' AND s.priority IS NOT NULL ORDER BY s.rank ASC";
 
 	# First one pass over the loop
@@ -211,7 +196,7 @@ sub __structure {
 		my $current_rank = delete $hash_ref->{rank};
 
 		# Now we need to add in any loop variables
-		$self->__populate_lower_loops($dlineage, $tlineage, $hash_ref, $current_rank, \@params);
+		$self->__populate_lower_loops($dlineage, $tlineage, $hash_ref, $current_rank, $param);
 
 		# We are finally ready to get this structure out of the door
 		push @loop, $hash_ref;
@@ -245,6 +230,10 @@ sub __populate_lower_loops {
 	my $comma = ',';
         my $new_dlineage = join $comma , (split /,/, $dlineage), $current_rank;
         my @new_tlineage = @$tlineage;
+        my $thead = pop @new_tlineage;
+	$thead .= ".structure";
+	$thead .= "('$param')" if $param;
+        push @new_tlineage, $thead;
         my @new_vars = $self->{template}->query(loop=>\@new_tlineage);
         foreach my $var (@new_vars) {
 
@@ -261,39 +250,14 @@ sub __populate_lower_loops {
                 # before populating this one
                 my $new_loop = [];
                 $current_row->{structure} = $new_loop;
-                my $new_tlineage = [@new_tlineage, $var];
+                my $new_tlineage = [@new_tlineage, $one];
                 push @{$self->{work_to_be_done}}, sub {
-                	push @$new_loop,  @{$self->__structure($param, $new_dlineage, $new_tlineage)};
+                	push @$new_loop,  @{$self->structure($param, $new_dlineage, $new_tlineage)};
                 };
         }
 	return;
 }
 
-=head2 slice
-
-This function is a variant of the C<< structure >> function, which allows one to specify a part of the menu.
-The first argument is the database lineage which is a string consisting of comma separated numbers. The other arguments 
-are as described under C<< structure >>. The slice function can only be used in the topmost TMPL_LOOP of a template.
-
-=cut
-
-sub slice {
-        my $self = shift;
-        my $dlineage = shift;
-        my $template = "$self->{name}.slice('$dlineage','";
-	my @params = @_;
-        if (scalar(@params) == 1) {
-                # legacy case
-                $template .= "$params[0]')";
-                @params = split /,/, $params[0];
-        }
-        else {
-                $template .= join "','", @params;
-                $template .= "')";
-        }
-        return $self->__structure(\@params, $dlineage, [$template]);
-}
-
 =head1 AUTHOR
 
 Nicholas Bamber, C<< <nicholas at periapt.co.uk> >>
@@ -304,6 +268,10 @@ Please report any bugs or feature requests to C<bug-cgi-application-plugin-pagel
 the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=CGI-Application-Plugin-PageLookup>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
+=head2 AUTOLOAD
+
+AUTOLOAD is quite a fraught subject. There is probably no perfect solution. See http://www.perlmonks.org/?node_id=342804 for a sample of the issues.
+
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
